The ``ThreePointDetector`` class
################################

.. autoclass:: pylife.stress.rainflow.ThreePointDetector
               :members:
               :undoc-members:
               :special-members: __init__
